# Import des bibliothèques
import wave
import os
import math
import numpy as np
import matplotlib.pyplot as plt

######################################################
# Paramètres du son généré
######################################################
# Nom du fichier à créer
nomFichier = 'son_compose.wav'
# Ouverture fichier en écriture
monSon = wave.open(nomFichier, 'w')
# Son monophonique (un seul canal)
nbCanal = 1
# Chaque échantillon est quantifié sur 1 octet (8 bits)
nbOctet = 1
# Fréquence d'échantillonnage à 44,1 kHz
fech = 44100
# Durée (en s)
duree = 2
# Nombre de points (un son d'une seconde comporte 44100 points)
nb_points = int(duree*fech)


parametres = (nbCanal, nbOctet, fech, nb_points, 'NONE', 'not compressed')
monSon.setparams(parametres)
######################################################




######################################################
# Son complexe joué – À COMPLÉTER
######################################################
A0 =    # amplitude de la fondamentale
A1 =    # amplitude de la première harmonique
A2 =    # amplitude de la deuxième harmonique
f0 =    # fréquence de la fondamentale (Hz)
f1 =    # fréquence de la première harmonique (Hz)
f2 =    # fréquence de la deuxième harmonique (Hz)



# Création du son
for i in range(nb_points):
    val = wave.struct.pack('B',int(64*(1 + A0*math.sin(2*math.pi*f0*i/fech)) + 64*(1 + A1*math.sin(2*math.pi*f1*i/fech)) + 64*(1 + A2*math.sin(2*math.pi*f2*i/fech))))
    monSon.writeframes(val)

######################################################  



######################################################
# Fermeture puis lecture du fichier son_compose.wav
######################################################
monSon.close()
os.system("start son_compose.wav")
######################################################




######################################################
# Représentation graphique
######################################################
N = 4 # nombre de périodes représentées

# Suppression des éventuels tracés précédents
plt.clf()

# Construction de l'axe des abscisses
t = np.linspace(0,N/f0,5001)

# Construction du signal
y = 100*(1 + A0*np.sin(2*np.pi*f0*t) + A1*np.sin(2*np.pi*f1*t) + A2*np.sin(2*np.pi*f2*t))


# Tracé du signal
plt.plot(t, y, "b")

# Noms des axes
plt.xlabel("Temps (en s)")
plt.xlim(0, N/f0)
plt.ylabel("Tension (échelle arbitraire)")

# Titre du graphique
plt.title("Représentation temporelle d'un signal sonore")
plt.grid()


# Affichage du graphique
plt.show()
######################################################